#!/usr/bin/env bash

# key name must be supplied
if [ -z "$1" ]; then
  echo "Usage: mkkey <name>" 1>&2
  exit 1
fi

base="$HOME/.ssh"

# create ~/.ssh if nonexistent
if [ ! -d "$base" ]; then
  mkdir $base
  chmod 700 $base
fi

# build filename
filename="$base/${1}.pem"

# skip if file exists
if [ -e "$filename" ]; then
  echo "$filename already exists!" 1>&2
  ssh-keygen -y -f $filename
  exit 1
fi

# setup directory
namespace=$(dirname $filename)
mkdir -p $namespace
chmod 700 $namespace

# generate key
openssl genrsa -out $filename 2048 2> /dev/null
chmod 600 $filename
ssh-keygen -y -f $filename
